import { LitElement } from 'lit';
declare type Constructor<T = {}> = new (...args: any[]) => T;
declare type NativeFormControlElement = HTMLInputElement;
export declare abstract class FormControlMixinInterface extends LitElement {
    formAssociated: boolean;
    get value(): FormDataEntryValue | FormData;
    set value(newValue: FormDataEntryValue | FormData);
    name: string;
    formResetCallback(): void;
    checkValidity(): boolean;
    get validationMessage(): string;
    get validity(): ValidityState;
    setCustomValidity(error: string): void;
    submit(): void;
    protected _value: FormDataEntryValue | FormData;
    protected _internals: any;
    protected abstract getFormElement(): HTMLElement | undefined;
    protected addValidator: (flagKey: FlagTypes, getMessageMethod: () => String, checkMethod: () => boolean) => void;
    protected addFormControlElement(element: NativeFormControlElement): void;
    pristine: boolean;
    required: boolean;
    requiredMessage: string;
    error: boolean;
    errorMessage: string;
}
declare type FlagTypes = 'badInput' | 'customError' | 'patternMismatch' | 'rangeOverflow' | 'rangeUnderflow' | 'stepMismatch' | 'tooLong' | 'tooShort' | 'typeMismatch' | 'valueMissing' | 'badInput' | 'valid';
/**
 * The mixin allows a custom element to participate in HTML forms.
 *
 * @param {Object} superClass - superclass to be extended.
 * @mixin
 */
export declare const FormControlMixin: <T extends Constructor<LitElement>>(superClass: T) => Constructor<FormControlMixinInterface> & T;
export {};
